.. llg documentation master file, created by
   sphinx-quickstart on Tue Dec 31 12:16:01 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to llg's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   authors
   code

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
